Trait atomic_enums::Atomize

source ·
pub trait Atomize: Into<u16> + From<u16> { }
The trait needs to be implemented for enumeration which shall be used with AtomicEnum. Additionally the traits Into<u16> and From<u16> have to be implemented.

An derive macro is implemented, make shure that you have a field with the name UnknownField is constructed!

Implementors